@@ -8,6 +8,7 @@ import shutil
 import zipfile
 from .httpclient import Session
 from .consts import NAME, VERSION
+from requests_toolbelt.multipart import encoder
 
 
 class Runner(Session):
@@ -228,19 +229,20 @@ class Runner(Session):
         url = self.api("jobs/{}/artifacts".format(job["id"]))
         trace.writeline("Uploading artifacts to gitlab..")
         with open(archive_file, "rb") as archive:
+            # solution to large uploads
+            # lifted from https://stackoverflow.com/questions/35779879/python-requests-upload-large-file-with-additional-data
+            form = encoder.MultipartEncoder({
+                "file": (os.path.basename(archive_file), archive, "application/octet-stream"),
+                "artifact_format": "zip",
+                "artifact_type": "archive"
+            })
+            headers = {
+                       "Content-Type": form.content_type,
+                       "Job-Token": job["token"]
+                       }
             resp = self.post(url,
-                             params={
-                                 "artifact_format": "zip",
-                                 "artifact_type": "archive"
-                             },
-                             headers={
-                                 "Job-Token": job["token"]
-                             },
-                             files={
-                                 "file": (os.path.basename(archive_file),
-                                          archive,
-                                          "application/octet-stream")
-                             })
+                             headers=headers,
+                             data=form)
         resp.raise_for_status()
         trace.writeline("Upload complete")
 
