@@ -119,7 +119,7 @@ def run():
         docker = False
 
         # loop forever to cope with some common errors that can come up
-        while not opts.once:
+        while True:
             if extype == "shell":
                 instance = runner.Runner(config["server"], config["token"])
             elif extype == "docker":
@@ -130,10 +130,10 @@ def run():
 
             try:
                 instance.shell = config["shell"]
-                while not opts.once:
+                while True:
+                    result = None
                     interval = 40
                     logmsg.info("Polling for jobs.. ({} sec)".format(interval))
-                    result = False
                     job = instance.poll()
                     if not job:
                         time.sleep(interval)
@@ -147,11 +147,24 @@ def run():
                                 instance.success(job)
                             else:
                                 instance.failed(job)
+                            if opts.once:
+                                break
 
             except (ConnectionError, HTTPError) as err:
-                logmsg.warning("comms exception {}".format(err))
-                logmsg.warning("sleeping..")
-                time.sleep(10)
+                aborted = False
+                if not result:
+                    if job:
+                        if err.response.status_code == 403:
+                            # job was aborted by the server
+                            aborted = True
+                if aborted:
+                    logmsg.info("Job {} was cancelled".format(job["id"]))
+                else:
+                    logmsg.warning("comms exception {}".format(err))
+                    logmsg.warning("sleeping..")
+                    time.sleep(10)
+            finally:
+                if opts.once:
+                    break
 
-        if exitstatus and opts.once:
-            sys.exit(exitstatus)
+        sys.exit(exitstatus)
